/*
		DataDescriptionWndProc.c - Data Description Window
		Dr. Rainer Sieger, Universitt Bremen
		07.01.2001
*/

#include <windows.h>
#include <stdlib.h>
#include <stdio.h>

#include "Struct.h"
#include "Globals.h"

#include "WndProc.h"
#include "Window.h"
#include "Fileselect.h"
#include "Do_FileMenu.h"
#include "Win_GUI.h"
#include "Dialog.h"

#include "ReadData.h"
#include "Preferences.h"
#include "Font.h"
#include "SetMemory.h"

LRESULT CALLBACK DataDescriptionWndProc (HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
{
	static HWND   hwndClient;
	static HWND		hwndFrame;
	static int  	indexText, indexTitle;
	static int		cxChar, cxCaps, cyChar, iMaxWidth, iMaxWidthTitle, iMaxWidthText;
	static int 		iVscrollPos, iVscrollMax, iHscrollPos, iHscrollMax;
	              
	int         	i, x, y, iPaintBeg, iPaintEnd, iVscrollInc, iHscrollInc;

	int					  length 		 	= 0;
	int					  maxlength  	= 0;
	int           err					= 0;
	int           MenuItem		= 0;

	StrFullName						StartEditor = "";

	STARTUPINFO 				 	si;
	PROCESS_INFORMATION 	pi;
	HDC										hdc;
	PAINTSTRUCT						ps;
	TEXTMETRIC						tm;

/*********************************************************************/
		 
	switch (iMsg)
	{
		case WM_CREATE :
			// Save some window handles
			hwndClient = GetParent (hwnd);
			hwndFrame  = GetParent (hwndClient);

			maxlength = 0;
			for (i=1;i<=gNumOfLines;i++)
			{
				length = (int) strlen((char *) DataDescription[i].Title);
				if (length > maxlength)
				{
					maxlength  = length;
					indexTitle = i;
				}
			}
	        
			maxlength = 0;
			for (i=1;i<=gNumOfLines;i++)
			{
				length = (int) strlen((char *) DataDescription[i].Text);
				if (length > maxlength)
				{
					maxlength = length;
					indexText = i;
				}
			}
			return 0;
			break;

		case WM_SIZE :
			gDataDescriptionWindowWidth  = LOWORD (lParam);
			gDataDescriptionWindowHeight = HIWORD (lParam);
			
			hdc = GetDC(hwnd);
 			SetFont(hdc,(char *) Font,FontSize,BOLD,0);               
			GetTextMetrics(hdc,&tm);
			cxChar 	 = tm.tmAveCharWidth;
			cxCaps 	 = (tm.tmPitchAndFamily & 1 ? 3 : 2) * cxChar/2;
			cyChar 	 = tm.tmHeight + tm.tmExternalLeading;
	                		
			iMaxWidthTitle = CalcTextWidth(hdc, (char *) DataDescription[indexTitle].Title,0,(int) strlen((char *) DataDescription[indexTitle].Title)) + cxChar;
			iMaxWidthText  = CalcTextWidth(hdc, (char *) DataDescription[indexText].Text,0,(int) strlen((char *) DataDescription[indexText].Text));
			iMaxWidth			= iMaxWidthTitle + iMaxWidthText + 5;
			ReleaseDC(hwnd,hdc);

			iVscrollMax = max (0, gNumOfLines + 2 - gDataDescriptionWindowHeight / cyChar);
			iVscrollPos = min (iVscrollPos, iVscrollMax);

			SetScrollRange (hwnd, SB_VERT, 0, iVscrollMax, FALSE);
			SetScrollPos   (hwnd, SB_VERT, iVscrollPos, TRUE);

			iHscrollMax = max (0, 2 + (iMaxWidth - gDataDescriptionWindowWidth) / cxChar);
			iHscrollPos = min (iHscrollPos, iHscrollMax);

			SetScrollRange (hwnd, SB_HORZ, 0, iHscrollMax, FALSE);
			SetScrollPos   (hwnd, SB_HORZ, iHscrollPos, TRUE);
			return 0;
			break;

		case WM_VSCROLL :
			switch (LOWORD (wParam))
			{
				case SB_TOP :
					iVscrollInc = -iVscrollPos;
					break;

				case SB_BOTTOM :
					iVscrollInc = iVscrollMax - iVscrollPos;
					break;

				case SB_LINEUP :
					iVscrollInc = -1;
					break;

				case SB_LINEDOWN :
					iVscrollInc = 1;
					break;

				case SB_PAGEUP :
					iVscrollInc = min (-1, -gDataDescriptionWindowHeight / cyChar);
					break;

				case SB_PAGEDOWN :
					iVscrollInc = max (1, gDataDescriptionWindowHeight / cyChar);
					break;

				case SB_THUMBTRACK :
					iVscrollInc = HIWORD (wParam) - iVscrollPos;
					break;

				default :
					iVscrollInc = 0;
					break;
			}

			iVscrollInc = max (-iVscrollPos, min (iVscrollInc, iVscrollMax - iVscrollPos));

			if (iVscrollInc != 0)
			{
				iVscrollPos += iVscrollInc;
				ScrollWindow (hwnd, 0, -cyChar * iVscrollInc, NULL, NULL);
				SetScrollPos (hwnd, SB_VERT, iVscrollPos, TRUE);
				UpdateWindow (hwnd);
			}
			return 0;
			break;

		case WM_HSCROLL :
			switch (LOWORD (wParam))
			{
				case SB_LINEUP :
					iHscrollInc = -1;
					break;

				case SB_LINEDOWN :
					iHscrollInc = 1;
					break;

				case SB_PAGEUP :
					iHscrollInc = -8;
					break;

				case SB_PAGEDOWN :
					iHscrollInc = 8;
					break;

				case SB_THUMBPOSITION :
					iHscrollInc = HIWORD (wParam) - iHscrollPos;
					break;

				default :
					iHscrollInc = 0;
					break;
			}

			iHscrollInc = max (-iHscrollPos, min (iHscrollInc, iHscrollMax - iHscrollPos));

			if (iHscrollInc != 0)
			{
				iHscrollPos += iHscrollInc;
				ScrollWindow (hwnd, -cxChar * iHscrollInc, 0, NULL, NULL);
				SetScrollPos (hwnd, SB_HORZ, iHscrollPos, TRUE);
			}
			return 0;
			break;

		case WM_PAINT :
			hdc = BeginPaint (hwnd, &ps);

 			SetFont(hdc,(char *) Font,FontSize,BOLD,0);               
			GetTextMetrics(hdc,&tm);
			cxChar 	 = tm.tmAveCharWidth;
			cxCaps 	 = (tm.tmPitchAndFamily & 1 ? 3 : 2) * cxChar/2;
			cyChar 	 = tm.tmHeight + tm.tmExternalLeading;
	    
			iMaxWidthTitle = CalcTextWidth(hdc, (char *) DataDescription[indexTitle].Title,0,(int) strlen((char *) DataDescription[indexTitle].Title)) + cxChar;
			iMaxWidthText  = CalcTextWidth(hdc, (char *) DataDescription[indexText].Text,0,(int) strlen((char *) DataDescription[indexText].Text));
			iMaxWidth			= iMaxWidthTitle + iMaxWidthText + 5;

			iPaintBeg = max (0, iVscrollPos + ps.rcPaint.top / cyChar - 1);
			iPaintEnd = min (gNumOfLines,iVscrollPos + ps.rcPaint.bottom / cyChar);
			
			for (i = iPaintBeg; i <= iPaintEnd; i++)
			{
				x = cxChar * (1 - iHscrollPos);
				y = cyChar * (i - iVscrollPos);
       	SetFont(hdc,(char *) Font,FontSize,BOLD,0);
				TextOut(hdc, x, y, (char *) DataDescription[i+1].Title,(int) strlen((char *) DataDescription[i+1].Title));
       	SetFont(hdc,(char *) Font,FontSize,NORMAL,0);
				TextOut(hdc, x+iMaxWidthTitle, y, (char *) DataDescription[i+1].Text,(int) strlen((char *) DataDescription[i+1].Text));
			}

			EndPaint (hwnd, &ps);
			return 0;
			break;

		case WM_MDIACTIVATE :
			// Set the Data Description menu if gaining focus
			if (lParam == (LPARAM) hwnd)
				SendMessage (hwndClient, WM_MDISETMENU, (WPARAM) hMenuDataDescription, (LPARAM) hMenuDataDescriptionWindow);
			
			// Set item New Data Plot Window
			if (gDataPlotWindow != 0)
				EnableMenuItem(hMenuDataDescription, IDM_OPENDATAPLOTWINDOW, MF_GRAYED);	 // New Data Plot Window
			else
				EnableMenuItem(hMenuDataDescription, IDM_OPENDATAPLOTWINDOW, MF_ENABLED); // New Data Plot Window

			// Set the Init menu if losing focus
			if (lParam != (LPARAM) hwnd)
				SendMessage (hwndClient, WM_MDISETMENU, (WPARAM) hMenuInit, (LPARAM) hMenuInitWindow);
								      
			DrawMenuBar (hwndFrame);
			gDataDescriptionWindowHeight = HIWORD(wParam);
			SendMessage (hwnd, WM_SIZE, wParam, lParam);		
			return 0;
			break;

		case WM_QUERYENDSESSION :
		case WM_CLOSE :
			GetClientWindowPos(hwndFrame,hwnd,&gClientDataDescriptionWindowX,&gClientDataDescriptionWindowY,&gClientDataDescriptionWindowWidth,&gClientDataDescriptionWindowHeight);
			GetFrameWindowPos(hwndFrame,&gFrameWindowX,&gFrameWindowY,&gFrameWindowWidth,&gFrameWindowHeight);
			SaveWindowPreferences();
			gDataDescriptionWindow = 0;
			break;   // I.e., call DefMDIChildProc

		case WM_DESTROY :
				return 0;
				break;

		case WM_COMMAND :
			MenuItem = LOWORD (wParam);
			switch (MenuItem)
			{
				case IDM_SAVEAS :
					err = Do_Saveas(hwnd, hInst, SaveData);
					DoCaptionDataPlotWindow(hwnd, (char *) FullName);
					InvalidateRgn (hwnd, NULL, TRUE); 
					return 0;
					break;
							
				case IDM_SAVEDATADESCRIPTION :
					err = Do_Saveas(hwnd, hInst, SaveDataDescription);

					if (DataDescriptionSaved == 1)
						EnableMenuItem(hMenuDataDescription, IDM_RELOADDATADESCRIPTION, MF_ENABLED);

					return 0;
					break;
							
				case IDM_SETMEMORY:
					Do_SetMemory(hwnd, hInst);
					return 0;
					break;

				case IDM_EDITDATADESCRIPTION :
					if (DataDescriptionSaved != 1)
						err = Do_Saveas(hwnd, hInst, SaveDataDescription);
					
					if (DataDescriptionSaved == 1)
					{
						if (ChooseEditor == 0)
						{
				 			FileInitialize (hwnd, EXE);
				 			GetWindowsDirectory((char *) EPath, MAX_PATH);
				 			strcpy((char *) Editor, (char *) EPath);
				 			strcat((char *) Editor, "\\");
				 			strcat((char *) Editor, (char *) EName);

							if (FileOpenDlg (hwnd, hInst, (char *) Editor, (char *) EPath, (char *) EName, "Select editor"))
         				ChooseEditor = 1;
         			else
         				sprintf((char *) Editor, "Notepad.exe");	
						}												  

						EnableMenuItem(hMenuDataDescription, IDM_RELOADDATADESCRIPTION, MF_ENABLED);										 	 
						EnableMenuItem(hMenuDataPlot, IDM_RELOADDATADESCRIPTION, MF_ENABLED);										 	 
						EnableMenuItem(hMenuInit, IDM_RELOADDATADESCRIPTION, MF_ENABLED);										 	 
						ZeroMemory(&si,sizeof(si)); 
						si.cb=sizeof(si);		
						strcpy((char *) StartEditor, (char *) Editor);		  
						strcat((char *) StartEditor, " ");
						strcat((char *) StartEditor, (char *) DDFullName);
						CreateProcess(NULL,(char *) StartEditor,NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);				
					}	
					return 0;
					break;

					case IDM_RELOADDATADESCRIPTION :
						err = ReloadDataDescription();
						InvalidateRgn (hwnd, NULL, TRUE);
						return 0;
						break;												 

					default:
						break;
				}

		default:
			break;
	}

	// Pass unprocessed message to DefMDIChildProc
	return(DefMDIChildProc (hwnd, iMsg, wParam, lParam));
}

/*********************************************************************/
/*********************************************************************/
/*********************************************************************/

void DoCaptionDataDescriptionWindow (HWND hwnd, char *szTitleName)
{
	char szCaption[64 + 256];
	wsprintf (szCaption, "Data description - %s", szTitleName[0] ? szTitleName : UNTITLED);
	SetWindowText (hwnd, szCaption);
}

/*********************************************************************/
/*********************************************************************/
/*********************************************************************/

HWND CreateDataDescriptionWindow(HWND hwndClient, HWND *hwndChild)
{	
	MDICREATESTRUCT  mdicreate;
	RECT	           ClientRect;

	if ((gClientDataDescriptionWindowHeight == -1) && (gClientDataDescriptionWindowWidth == -1))
	{
		GetClientRect(hwndClient,&ClientRect);
		gClientDataDescriptionWindowHeight = ClientRect.bottom - ClientRect.top - 30;
		gClientDataDescriptionWindowWidth  = ClientRect.right - ClientRect.left - 30;
	}

	mdicreate.szClass = szDataDescriptionClass;
	mdicreate.szTitle = "Data Description";
	mdicreate.hOwner  = hInst;
	mdicreate.x       = gClientDataDescriptionWindowX;
	mdicreate.y       = gClientDataDescriptionWindowY;
	mdicreate.cx      = gClientDataDescriptionWindowWidth;
	mdicreate.cy      = gClientDataDescriptionWindowHeight;
	mdicreate.style   = WS_VSCROLL | WS_HSCROLL;
	mdicreate.lParam  = 0;

	*hwndChild = (HWND) SendMessage (hwndClient, WM_MDICREATE, 0, (LPARAM) (LPMDICREATESTRUCT) &mdicreate);
	                                
	gDataDescriptionWindow = 1;

	return(0);
}

