/*--------------------------------------------*/
/*  Do_GraphicDialog - Graphikdialog          */
/*  Dr. Rainer Sieger, AWI-Bremerhaven        */
/*  25.03.2001                                */
/*--------------------------------------------*/

#include <windows.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "Struct.h"
#include "Globals.h"

#include "Font.h"
#include "Win_GUI.h"
#include "Do_GraphicDialog.h"
#include "Color.h"
#include "Dialog.h"
#include "replaceStr.h"

BOOL CALLBACK Do_GraphicDialog (HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam)
{
	int									j								= 0;

	char								iFormatStr[32]	= "%d";
	char								fFormatStr[32]	= "%.1f";

	BOOL								err							= TRUE;

	static CHOOSECOLOR	cc;
	static CHOOSEFONT		cf;

	static BOOL					fColorDialog;
	static BOOL					fFontDialog;

	static float	      resWindowWidth;
	static float	      resWindowHeight;
	static float				resWindowOffset;    
	static float				res;

	static int					dUseColor;
	static int					dUseDefaultColor;
	static int					dAllInOne;
	static int					dUnit;
	static int					dUseTemplate;
	static int					dTicklineWidth;
	static int					dKoorLineWidth;
	static int					dTerIncrement;
	static int					dCRDateTime;
	static int					dCRFilename;
	static int					dTextOrientation;
	static int					IDC_RadioUnit[maxRadio+1]							= {0,IDC_UNITA,IDC_UNITB,0};
	static int					IDC_RadioTextOrientation[maxRadio+1]	= {0,IDC_LANDSCAPE,IDC_PORTRAIT,0};

	static HWND  				hTicklineWidth 												= NULL;
	static HWND  				hEditTicklineWidth										= NULL;
	static HWND  				hKoorlineWidth 												= NULL;
	static HWND  				hEditKoorlineWidth										= NULL;
	static HWND  				hTerIncrement 												= NULL;
	static HWND  				hEditTerIncrement											= NULL;

	static Str255				dCopyrighttext = "";

// *************************************************************************

	switch (iMsg)
	{
		case WM_INITDIALOG :
			memset(&cf,0,sizeof(CHOOSEFONT));

			cf.lStructSize		= sizeof(CHOOSEFONT);
			cf.hwndOwner			= hDlg;
			cf.Flags					= CF_LIMITSIZE | CF_SCREENFONTS | CF_ANSIONLY |CF_INITTOLOGFONTSTRUCT;
			cf.nSizeMin				= 5;
			cf.nSizeMax				= 40;
			cf.lpLogFont			= &lf;

			fColorDialog			= FALSE;
			fFontDialog				= FALSE;

			res								= (float) cxDpi/2.54f;
			resWindowWidth		= (float) gDataPlotWindowWidth/res;
			resWindowHeight		= (float) gDataPlotWindowHeight/res;
			resWindowOffset		= (float) WindowOffset/res;

			dTicklineWidth		= ST[0].LineWidth;
			dKoorLineWidth		= KoorLineWidth;
			dUseColor					= useColor;
			dUseDefaultColor	= useDefaultColor;
			dUseTemplate			= useTemplate;
			dAllInOne					= AllInOne;
			dUnit							= UnitFormat;
			dCRDateTime				= CRDateTime;
			dCRFilename				= CRFilename;
			dTerIncrement			= TerIncrement;

			SetCheckButton(hDlg, IDC_USECOLOR, Set, &dUseColor);
			SetCheckButton(hDlg, IDC_USEDEFAULTCOLOR, Set, &dUseDefaultColor);
			SetCheckButton(hDlg, IDC_USETEMPLATE, Set, &dUseTemplate);
			SetCheckButton(hDlg, IDC_ALLINONE, Set, &dAllInOne);
			SetCheckButton(hDlg, IDC_CRDateTime, Set, &dCRDateTime);
			SetCheckButton(hDlg, IDC_CRFilename, Set, &dCRFilename);

			dUnit						= SetRadioButton(hDlg, 2, IDC_RadioUnit, UnitFormat);

			fColorDialog		= ColorDialog(hDlg, &cc, Set, &Color[0]);

			resWindowWidth  = FloatDialog(hDlg, IDC_WINDOWWIDTH,  Set, fFormatStr, resWindowWidth, err);
			resWindowHeight = FloatDialog(hDlg, IDC_WINDOWHEIGHT, Set, fFormatStr, resWindowHeight, err);
			resWindowOffset = FloatDialog(hDlg, IDC_DISTANCE,     Set, fFormatStr, resWindowOffset, err);

			dTicklineWidth  = IntegerDialog(hDlg, IDC_TICKLINEWIDTH, Set, iFormatStr, dTicklineWidth, err);
			dKoorLineWidth  = IntegerDialog(hDlg, IDC_KOORLINEWIDTH, Set, iFormatStr, dKoorLineWidth, err);
			dTerIncrement   = IntegerDialog(hDlg, IDC_GTICKINCREMENT, Set, iFormatStr, dTerIncrement, err);

			InitUpDownControl(hDlg,IDC_TICKLINEWIDTH,1,10,dTicklineWidth,&hTicklineWidth,&hEditTicklineWidth);
			InitUpDownControl(hDlg,IDC_KOORLINEWIDTH,1,10,dKoorLineWidth,&hKoorlineWidth,&hEditKoorlineWidth);

			if ((Mode == TernaryMode) || (Mode == PhaseMode))
			InitUpDownControl(hDlg,IDC_GTICKINCREMENT,1,50,dTerIncrement,&hTerIncrement,&hEditTerIncrement);

			TextDialog(hDlg, IDC_COPYRIGHTTEXT, Set, (char *) Copyrighttext);
			SetFocus(hDlg);
			return FALSE;
			break;

		case WM_VSCROLL :
			if ((HWND) lParam == hTicklineWidth) UpDown(hTicklineWidth,wParam);
			if ((HWND) lParam == hKoorlineWidth) UpDown(hKoorlineWidth,wParam);
			if ((HWND) lParam == hTerIncrement) UpDown(hTerIncrement,wParam);
			return FALSE;
			break;

		case WM_COMMAND :
			switch (LOWORD (wParam))
			{
				case IDOK :
					useColor					= dUseColor;
					useDefaultColor	= dUseDefaultColor;
					useTemplate			= dUseTemplate;
					AllInOne					= dAllInOne;
					CRDateTime				= dCRDateTime;
					CRFilename				= dCRFilename;

					if (fColorDialog)
						fColorDialog = ColorDialog(hDlg, &cc, Change, &Color[0]);
					
					if (useColor)
					{
						switch (Mode)
						{
						case HorizontalMode:
						case VerticalMode:
								if (useDefaultColor)
									SetColor(MAXNUMOFPARAMETERS,Color,GColor,DColor,init);
								else
									SetColor(MAXNUMOFPARAMETERS,Color,GColor,DColor,set);
								break;	
						case TernaryMode:
						case PhaseMode:
								SetColor(MAXNUMOFPARAMETERS,Color,GColor,DColor,set);
								break;
						}
					}
					else
					{
						SetBlack();
					}

					if (fFontDialog)
					{
						switch (Mode)
						{
							case HorizontalMode:
							case VerticalMode:
								strcpy((char *) Font, (char *) lf.lfFaceName);
								FontSize = cf.iPointSize/10;
								
								if (FontSize < 5)
									FontSize = 10;
							break;  	
						
							case TernaryMode:
							case PhaseMode:
								strcpy((char *) Font, (char *) lf.lfFaceName);
								GFontSize = cf.iPointSize/10;
							
								if (GFontSize < 5)
									GFontSize = 10;
								break; 
						}
					}

					resWindowWidth   = FloatDialog(hDlg,   IDC_WINDOWWIDTH,   Change, fFormatStr, resWindowWidth, err);
					resWindowHeight  = FloatDialog(hDlg,   IDC_WINDOWHEIGHT,  Change, fFormatStr, resWindowHeight, err);
					resWindowOffset  = FloatDialog(hDlg,   IDC_DISTANCE,      Change, fFormatStr, resWindowOffset, err);
					ST[0].LineWidth  = IntegerDialog(hDlg, IDC_TICKLINEWIDTH, Change, iFormatStr, dTicklineWidth, err);
					KoorLineWidth    = IntegerDialog(hDlg, IDC_KOORLINEWIDTH, Change, iFormatStr, dKoorLineWidth, err);
					TerIncrement     = IntegerDialog(hDlg, IDC_GTICKINCREMENT,Change, iFormatStr, dTerIncrement, err);

					if (TerIncrement < 1) 
						TerIncrement = 1;
					if (TerIncrement > 50)
						TerIncrement = 50;

					if (ST[0].LineWidth < 1) ST[0].LineWidth =  1;
					if (KoorLineWidth < 1)   KoorLineWidth   =  1;

					gDataPlotWindowWidth  = (int) (resWindowWidth*res);
					gDataPlotWindowHeight = (int) (resWindowHeight*res);
					WindowOffset    			= (int) (resWindowOffset*res);

					if (gDataPlotWindowWidth < 100)
						gDataPlotWindowWidth = 100;
					if (gDataPlotWindowHeight < 100)
						gDataPlotWindowHeight = 100;

					TextDialog(hDlg, IDC_COPYRIGHTTEXT, Change, (char *) Copyrighttext);

					EndDialog (hDlg, TRUE);

					if (dUnit != UnitFormat)
					{
						if (UnitFormat == 1)
						{
							for (j=0;j<=gNumOfParameters;j++)
							{
								replaceStr((char *) C[j].Header,"[","(");
								replaceStr((char *) C[j].Header,"]",")");
							}
						}
						else
						{
							for (j=0;j<=gNumOfParameters;j++)
							{
								replaceStr((char *) C[j].Header,"(","[");
								replaceStr((char *) C[j].Header,")","]");
							}
						}

						j = 0;

						if (UnitFormat == 1)
						{
							while (++j<=MAXNUMOFCOLORS)
							{
								if (DColor[j].Flag > 0)
								{
								replaceStr((char *) DColor[j].Name,"[","(");
								replaceStr((char *) DColor[j].Name,"]",")");
								}
								else
								j = 2*MAXNUMOFCOLORS;
							}
						}
						else
						{
							while (++j<=MAXNUMOFCOLORS)
							{
								if (DColor[j].Flag > 0)
								{
 								replaceStr((char *) DColor[j].Name,"(","[");
								replaceStr((char *) DColor[j].Name,")","]");
								}
								else
								j = 2*MAXNUMOFCOLORS;
							}
						}
					}					
					return TRUE;
					break;

				case IDC_WINDOWWIDTH :
					if (!(err = CheckValue(hDlg, IDC_WINDOWWIDTH)))
						resWindowWidth  = FloatDialog(hDlg, IDC_WINDOWWIDTH, Set, fFormatStr, resWindowWidth, err);
					else
						resWindowWidth  = FloatDialog(hDlg, IDC_WINDOWWIDTH, Change, fFormatStr, resWindowWidth, err);
					return TRUE;
					break;

				case IDC_WINDOWHEIGHT :
					if (!(err = CheckValue(hDlg, IDC_WINDOWHEIGHT)))
						resWindowHeight  = FloatDialog(hDlg, IDC_WINDOWHEIGHT, Set, fFormatStr, resWindowHeight, err);
					else
						resWindowHeight  = FloatDialog(hDlg, IDC_WINDOWHEIGHT, Change, fFormatStr, resWindowHeight, err);
					return TRUE;
					break;

				case IDC_DISTANCE :
					if (!(err = CheckValue(hDlg, IDC_DISTANCE)))
						resWindowOffset  = FloatDialog(hDlg, IDC_DISTANCE, Set, fFormatStr, resWindowOffset, err);
					else
						resWindowOffset  = FloatDialog(hDlg, IDC_DISTANCE, Change, fFormatStr, resWindowOffset, err);
					return TRUE;
					break;

				case IDC_TICKLINEWIDTH :
					if (!(err = CheckValue(hDlg, IDC_TICKLINEWIDTH)))
						dTicklineWidth  = IntegerDialog(hDlg, IDC_TICKLINEWIDTH, Set, iFormatStr, dTicklineWidth, err);
					else
						dTicklineWidth  = IntegerDialog(hDlg, IDC_TICKLINEWIDTH, Change, iFormatStr, dTicklineWidth, err);
					return TRUE;
					break;

				case IDC_KOORLINEWIDTH :
					if (!(err = CheckValue(hDlg, IDC_KOORLINEWIDTH)))
						dKoorLineWidth  = IntegerDialog(hDlg, IDC_KOORLINEWIDTH, Set, iFormatStr, dKoorLineWidth, err);
					else
						dKoorLineWidth  = IntegerDialog(hDlg, IDC_KOORLINEWIDTH, Change, iFormatStr, dKoorLineWidth, err);
					return TRUE;
					break;

				case IDC_GTICKINCREMENT :
					if (!(err = CheckValue(hDlg, IDC_GTICKINCREMENT)))
						dTerIncrement  = IntegerDialog(hDlg, IDC_GTICKINCREMENT, Set, iFormatStr, dKoorLineWidth, err);
					else
						dTerIncrement  = IntegerDialog(hDlg, IDC_GTICKINCREMENT, Change, iFormatStr, dKoorLineWidth, err);
					return TRUE;
					break;

				case IDC_USECOLOR :
					SetCheckButton(hDlg, IDC_USECOLOR, Change, &dUseColor);
					return TRUE;
					break;

				case IDC_USEDEFAULTCOLOR :
					SetCheckButton(hDlg, IDC_USEDEFAULTCOLOR, Change, &dUseDefaultColor);
					return TRUE;
					break;

				case IDC_USETEMPLATE :
					SetCheckButton(hDlg, IDC_USETEMPLATE, Change, &dUseTemplate);
					return TRUE;
					break;

				case IDC_ALLINONE :
					SetCheckButton(hDlg, IDC_ALLINONE, Change, &dAllInOne);
					return TRUE;
					break;

				case IDC_UNITA :
					UnitFormat = SetRadioButton(hDlg, 2, IDC_RadioUnit, 1);
					return TRUE;
					break;

				case IDC_UNITB :
					UnitFormat = SetRadioButton(hDlg, 2, IDC_RadioUnit, 2);
					return TRUE;
					break;

				case IDC_CRDateTime :
					SetCheckButton(hDlg, IDC_CRDateTime, Change, &dCRDateTime);
					return TRUE;
					break;

				case IDC_CRFilename :
					SetCheckButton(hDlg, IDC_CRFilename, Change, &dCRFilename);
					return TRUE;
					break;

				case IDC_CHOOSEFONT :
					fFontDialog = ChooseFont(&cf);
					return TRUE;
					break;

				case IDC_TICKLINECOLOR :
					fColorDialog = ColorDialog(hDlg, &cc, Choose, &Color[0]);
					return TRUE;
					break;

				case IDCANCEL :
					EndDialog (hDlg, FALSE);
					return TRUE;
					break;

				default:
					break;
			}
			break;

		case WM_PAINT :
			break;
	}

	return FALSE;
}

