/*
		FrameWndProc.c - Frame Window
		Dr. Rainer Sieger, Universitt Bremen
		26.10.2000
*/

#include <windows.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "Struct.h"
#include "Globals.h"

#include "WndProc.h"
#include "Win_GUI.h"
#include "Dialog.h"
#include "Do_FileMenu.h"
#include "Fileselect.h"
#include "EnableMenu.h"
#include "DisableMenu.h"
#include "SetMenuItems.h"
#include "Window.h"
#include "SetMemory.h"

#include "ResetFilename.h"
#include "SplitDataFile.h"
#include "ReadData.h"
#include "Preferences.h"

LRESULT CALLBACK FrameWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
{
	static HWND         hwndClient;
	static HWND         hwndEdit;

	CLIENTCREATESTRUCT  clientcreate;
	HWND                hwndChild;

	int									err				= 0;
	int									MenuItem	= 0;

//---------------------------------------------------------------------------------------

  switch (iMsg)
  {
    case WM_CREATE :          // Create the client window
      clientcreate.hWindowMenu  = hMenuInitWindow; 
      clientcreate.idFirstChild = IDM_FIRSTCHILD;
      hwndClient = CreateWindow ("MDICLIENT", NULL,
                    WS_CHILD | WS_CLIPCHILDREN | WS_VISIBLE,
                    0, 0, 0, 0, hwnd, (HMENU) 1, hInst,
                    (LPSTR) &clientcreate);
      return 0;
			break;

    case WM_COMMAND :
			MenuItem = LOWORD (wParam);

			switch (MenuItem)
      {
				case IDM_RELOAD :									  
					AutoLoadData = 1;
							
				case IDM_OPEN :
					EnumChildWindows(hwndClient, &CloseEnumProc, 0);

					if (gDataPlotWindow > 0)
					{
						if (gDataDescriptionWindow == 0)
							EnableMenuItem(hMenuDataPlot, IDM_OPENDATADESCRIPTIONWINDOW, MF_ENABLED);
					}
					else
					{
						EnableMenuItem(hMenuInit, IDM_OPENDATADESCRIPTIONWINDOW, MF_GRAYED); // New Data Plot Window
						EnableMenuItem(hMenuInit, IDM_OPENDATAPLOTWINDOW, MF_GRAYED);		     // New Data Plot Window

						gDataPlotWindow					= -1;
						gDataDescriptionWindow	= -1;
						DataDescriptionSaved		=  0;

						if (AutoLoadData < 1)
		 					err = Do_Open(hwnd, hInst, LoadDataRequest);
						else
		 					err = Do_Open(hwnd, hInst, LoadData);

						if (err == 0)
						{
							if (gNumOfLines > 0)
							{
								CreateDataDescriptionWindow(hwndClient, &hwndChild);	
								DoCaptionDataDescriptionWindow(hwndChild, (char *) FullName);
								EnableMenuItem(hMenuInit, IDM_OPENDATADESCRIPTIONWINDOW, MF_ENABLED);
								EnableMenuItem(hMenuDataDescription, IDM_SAVEDATADESCRIPTION, MF_ENABLED);
							}

							CreateDataPlotWindow(hwndClient, &hwndChild);	
							DoCaptionDataPlotWindow(hwndChild, (char *) FullName);
							EnableMenuItem(hMenuInit, IDM_OPENDATAPLOTWINDOW, MF_ENABLED);
							EnableMenuItem(hMenuDataDescription, IDM_RELOADDATADESCRIPTION, MF_GRAYED);

  	  				SetMenuItems(hSubMenuOptions);
							EnableMenu(hwnd, hMenuDataPlot, hSubMenuFile, hSubMenuEdit, hSubMenuOptions, hSubMenuYAxis, hSubMenuSetAll);
							InvalidateRgn(hwnd, NULL, TRUE); 
						}
						else
						{
							switch (gNumOfParameters)
							{
								case -1:
	        				err = Do_StopAlert(hwnd,rFileError);
									break;

								case -2:
		       				err = Do_StopAlert(hwnd,rWrongData);
									break;

								default:
									break;
							}

							if (err != -2)
							{
								ResetFilename();
								DisableMenu (hwnd, hMenuDataPlot, hSubMenuFile, hSubMenuEdit, hSubMenuOptions);
							}
						}
					}
					return 0;
					break;
							
				case IDM_OPENDATADESCRIPTIONWINDOW :
					if (gDataDescriptionWindow == 0)
					{
						CreateDataDescriptionWindow(hwndClient, &hwndChild);	
						DoCaptionDataDescriptionWindow(hwndChild, (char *) FullName);													
						gDataDescriptionWindow = 1;
					}
          return 0;
					break;

		    case IDM_OPENDATAPLOTWINDOW : 
					if (gDataPlotWindow == 0)
					{
						CreateDataPlotWindow(hwndClient, &hwndChild);	
						DoCaptionDataPlotWindow(hwndChild, (char *) FullName);													
						gDataPlotWindow = 1;
					}
          return 0;
					break;

// Messages from Help menu
        case IDM_INFO :
          Do_CautionAlert (hwnd, rInfo);
          return 0;
					break;

        case IDM_VERSION :
          Do_CautionAlert (hwnd, rVersion); 
          return 0;
					break;

        case IDM_HELP :
          OkMessage (hwnd, "Please, read the fine manual\nhttp://www.pangaea.de/Software/PanPlot", "\0");
          return 0;
					break;

        case IDM_ABOUT :
          DialogBox (hInst, "ABOUTBOX", hwnd, (DLGPROC) AboutDlgProc);
          return 0;
					break;

// Messages from program
        case IDM_CLOSE :          // Close the active window
          hwndChild = (HWND) SendMessage (hwndClient, WM_MDIGETACTIVE, 0, 0);

          if (SendMessage (hwndChild, WM_QUERYENDSESSION, 0, 0))
              SendMessage (hwndClient, WM_MDIDESTROY, (WPARAM) hwndChild, 0);

					return 0;
					break;

				case IDM_SETMEMORY:
					Do_SetMemory(hwnd, hInst);
					break;

        case IDM_EXIT :           // Exit the program
          SendMessage (hwnd, WM_CLOSE, 0, 0);
          return 0;
					break;

                        // messages for arranging windows
        case IDM_TILE :
          SendMessage (hwndClient, WM_MDITILE, 0, 0);
          return 0;
					break;

        case IDM_CASCADE :
          SendMessage (hwndClient, WM_MDICASCADE, 0, 0);
          return 0;
					break;

        case IDM_ARRANGE :
          SendMessage (hwndClient, WM_MDIICONARRANGE, 0, 0);
          return 0;
					break;

        case IDM_CLOSEALL :       // Attempt to close all children
					if (gDataPlotWindow > 0)
					{
//					err = Do_StopAlert(hwnd, rSaveGraphic);

						err	= IDNO;
						switch (err)
			  		{
					   	case IDCANCEL: 
	    	   			return 0; 
	    	   			break;
	    	
							case IDYES: 
	    	   			err = Do_Saveas(hwnd, hInst, ExportPICT);
	    	   			break;
					 		
							case IDNO:     
					 			break;

							default:
								break;
						}
					}

					gDataPlotWindow--;
					gDataDescriptionWindow--;
          EnumChildWindows (hwndClient, &CloseEnumProc, 0);
          return 0;
					break;

        default :            // Pass to active child...
          hwndChild = (HWND) SendMessage (hwndClient, WM_MDIGETACTIVE, 0, 0);
          if (IsWindow (hwndChild))
            SendMessage (hwndChild, WM_COMMAND, wParam, lParam);
          break;        // ...and then to DefFrameProc
      }
      break;

    case WM_QUERYENDSESSION :
    case WM_CLOSE :                     // Attempt to close all children
      SendMessage (hwnd, WM_COMMAND, IDM_CLOSEALL, 0);
      if (NULL != GetWindow (hwndClient, GW_CHILD))
        return 0;
      break;   // I.e., call DefFrameProc 

    case WM_DESTROY :
			PostQuitMessage (0);
			return 0;

		default:
			break;
  }

	// Pass unprocessed messages to DefFrameProc (not DefWindowProc)
  return DefFrameProc (hwnd, hwndClient, iMsg, wParam, lParam);
}

//-------------------------------------------------------------

BOOL CALLBACK CloseEnumProc (HWND hwnd, LPARAM lParam)
{
	if (GetWindow (hwnd, GW_OWNER))         // Check for icon title
		return 1;

	SendMessage (GetParent (hwnd), WM_MDIRESTORE, (WPARAM) hwnd, 0);

	if (!SendMessage (hwnd, WM_QUERYENDSESSION, 0, 0))
		return 1;

	SendMessage (GetParent (hwnd), WM_MDIDESTROY, (WPARAM) hwnd, 0);
		return 1;
}


