/*********************************************************************
*                                                                    *
*     Init.c                                                         *
*                                                                    *
*     Programmautor: Rainer Sieger, Alfred-Wegener-Institut          *
*     Datei erstellt am: 3.8.94                                      *
*     Letzte Aenderung: 2007-08-01                                   *
*                                                                    *
*********************************************************************/

#include <windows.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "Struct.h"
#include "Globals.h"

#include "Win_GUI.h"
#include "DisableMenu.h"
#include "Dialog.h"
#include "PrintTools.h"
#include "Window.h"
#include "FileSystem.h"
#include "Fileselect.h"
#include "Preferences.h"
#include "Initialize.h"
#include "Color.h"
#include "SetMouseCursor.h"
#include "replaceStr.h"
#include "Font.h"

// ------------------------------------------------------------------------------------------------
// Initialize setzt die globalen Variablen auf ihre Ausgangswerte und koordiniert den
// weiteren Initialisierungsproze.
// ------------------------------------------------------------------------------------------------

int Initialize()
{
  int							err							= 0;
	unsigned long   usedMemorySize	= 0;

//------------------------------------------------------------------
// Speicher allozieren	

  usedMemorySize += (unsigned long) (MAXNUMOFFILES+1)*sizeof(StrName);	  	  			// Filelist
  if ((Filelist = (StrName *) malloc((MAXNUMOFFILES+1)*sizeof(StrName))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFPARAMETERS+1)*sizeof(RGBColor);  			// Color
  if ((Color = (RGBColor *)	malloc((MAXNUMOFPARAMETERS+1)*sizeof(RGBColor))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFPARAMETERS+1)*sizeof(RGBColor);  			// GColor
  if ((GColor = (RGBColor *) malloc((MAXNUMOFPARAMETERS+1)*sizeof(RGBColor))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCOLORS+1)*sizeof(DefaultColor);   	 		// DColor
  if ((DColor = (DefaultColor *) malloc((MAXNUMOFCOLORS+1)*sizeof(DefaultColor))) == NULL)
  	return(-1);

	usedMemorySize += (unsigned long) (MAXNUMOFBITMAPS+1)*sizeof(BitmapPattern);      // Pattern
  if ((BitPattern	= (BitmapPattern *) malloc((MAXNUMOFBITMAPS+1)*sizeof(BitmapPattern))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFITEM+1)*sizeof(DialogItem);     				// Item
  if ((Item	= (DialogItem *) malloc((MAXNUMOFITEM+1)*sizeof(DialogItem))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCHAR+1)*sizeof(char);					  			// InputStr
  if ((InputStr = (char *) malloc((MAXNUMOFCHAR+1)*sizeof(char))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCHAR+1)*sizeof(char);					  			// TempStr
  if ((TempStr = (char *)	malloc((MAXNUMOFCHAR+1)*sizeof(char))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCHAR+1)*sizeof(char);					  			// TempStr
  if ((ReplaceTempStr = (char *)	malloc((MAXNUMOFCHAR+1)*sizeof(char))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCHAR+1)*sizeof(char);					  			// HeaderStr1
  if ((HeaderStr1 = (char *)	malloc((MAXNUMOFCHAR+1)*sizeof(char))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCHAR+1)*sizeof(char);					  			// HeaderStr2
  if ((HeaderStr2 = (char *)	malloc((MAXNUMOFCHAR+1)*sizeof(char))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (MAXNUMOFCOMMENTS+1)*sizeof(DDData);						// Data Description
  if ((DataDescription = (DDData *)	malloc((MAXNUMOFCOMMENTS+1)*sizeof(DDData))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (maxPTData+1)*sizeof(POINT);										// Polygonpunkte
  if ((PT = (POINT *)	malloc((maxPTData+1)*sizeof(POINT))) == NULL)  
  	return(-1);
  
  usedMemorySize += (unsigned long) (MAXNUMOFPARAMETERS+1)*sizeof(Options);
  if ((ST = (Options *) malloc((MAXNUMOFPARAMETERS+1)*sizeof(Options))) == NULL) 
  	return(-1);
  
  usedMemorySize += (unsigned long) (MAXSPLITNUMOFPARAMETERS+1)*sizeof(Container);
	if ((C = (Container *) calloc((MAXSPLITNUMOFPARAMETERS+1),sizeof(Container))) == NULL)
  	return(-1);

  usedMemorySize += (unsigned long) (gMaxCData+1)*sizeof(CData); 
  if ((T = (CData *) calloc((gMaxCData+1),sizeof(CData))) == NULL)
  	return(-1);
		   
  usedMemorySize += (unsigned long) (gMaxMData+1)*sizeof(Data); 
  if ((Q = (Data *) calloc((gMaxMData+1),sizeof(Data))) == NULL)
  	return(-1);

//------------------------------------------------------------------

	AutoLoadData						= 0;

	gDataPlotWindow					= -1;
	gDataDescriptionWindow	= -1;
  gDataPlotWindowWidth		= -1;
  gDataPlotWindowHeight		= -1;
	
  SetDefaultMouseCursor(); 

  InitFont();
  InitColor();

  if (InitPattern())
		InitPattern();
    
  return(0);
}

// ---------------------------------------------------------
// ---------------------------------------------------------
// ---------------------------------------------------------

void InitWindows()
{
		gFrameWindowX			  = GetSystemMetrics(SM_CXSCREEN)/20;
		gFrameWindowWidth   = GetSystemMetrics(SM_CXSCREEN) - 2*gFrameWindowX;

		gFrameWindowY			  = GetSystemMetrics(SM_CYSCREEN)/20;
		gFrameWindowHeight  = GetSystemMetrics(SM_CYSCREEN) - 2*gFrameWindowY;

		gClientDataDescriptionWindowX			= (int) (gFrameWindowWidth/70);
		gClientDataDescriptionWindowY			= (int) (gFrameWindowHeight/70);
		gClientDataPlotWindowX						= (int) (gFrameWindowWidth/25);
		gClientDataPlotWindowY						=	(int) (gFrameWindowHeight/15);

		gClientDataDescriptionWindowWidth		= gFrameWindowWidth - gClientDataPlotWindowX - 20;
		gClientDataDescriptionWindowHeight	= gFrameWindowHeight - gClientDataPlotWindowY - 60;	 

		gClientDataPlotWindowWidth	= gClientDataDescriptionWindowWidth;
		gClientDataPlotWindowHeight	= gClientDataDescriptionWindowHeight;
}

// ---------------------------------------------------------
// ---------------------------------------------------------
// ---------------------------------------------------------

void InitFont(void)
{
	memset(&lf,0,sizeof(LOGFONT));
	strcpy((char *) lf.lfFaceName,"Arial");
 	strcpy((char *) Font, "Arial");
}

// ---------------------------------------------------------
// ---------------------------------------------------------
// ---------------------------------------------------------

void InitST(void)
{
	int  j;

	int   top;
	int		left;
	int   height;
	int   width;

	char  *p;

// ******************************

	maxWindowSize(&top,&left,&height,&width);

	TerIncrement		= 20;
	GroupDistance		= 10;

	useColor			  = 1;
	useDefaultColor = 1;
	CRFilename		  = 1;
	CRDateTime		  = 1;
	UnitFormat      = 1;

	if ((p = strrchr((char *) Copyrighttext, (int) '@')) == NULL)
		strcpy((char *) Copyrighttext, "PANGAEA/PanPlot");
		
	for (j=0;j<=MAXNUMOFPARAMETERS;j++)
	{
		strcpy((char *) ST[j].FormatStr, "%.2f");			
		ST[j].PlotData            			= 0;
		ST[j].PlotMarker          			= 0;
		ST[j].PlotLine            			= 0;
		ST[j].PlotCHistogramm     			= 0;
 		ST[j].PlotLHistogramm     			= 0;
 		ST[j].PlotOHistogramm     			= 0;
 		ST[j].PlotOccurrence       			= 0;
 		ST[j].PlotText            			= 0;
 		ST[j].PlotComment        		 		= 1;
 		ST[j].PlotLitho           			= 0;
 		ST[j].PlotBounds          			= 0;
 		ST[j].PlotCourse          			= 0;
 		ST[j].PlotParametername					= 0;
 		ST[j].PlotGroupname							= 0;
		ST[j].AddNext             			= 0;
		ST[j].Colorize            			= 0;
		ST[j].SetDefaultRange     			= 1;
		ST[j].ReverseRange		     			= 0;
		ST[j].ShowValid									= 1;
		ST[j].ShowNotValid							= 0;
		ST[j].ShowUnknown								= 0;
		ST[j].ShowQuestionable					= 0;
		ST[j].ShowMissingData						= 0;
		ST[j].BothSide	          			= 0;
		ST[j].Inside              			= 0;
		ST[j].ParameterTextOrientation	= 0;
		ST[j].MLineWidth          			= 1;
		ST[j].ColumnWidth         			= 10;
		ST[j].Minor_Ticks         			= 1;
		ST[j].Tickline            			= 1;
		ST[j].Minor_Tickline      			= 0;
		ST[j].Tick_Increment      			= (float) 0.;
		ST[j].min                 			= (float) 0.;
		ST[j].max                 			= (float) 0.;
		ST[j].Refline             			= (float) 0.;
		ST[j].fixedParameterWidth 			= 0;
		ST[j].ParameterWidth      			= 0;
		ST[j].GroupNo 									= 1;
		ST[j].GPlotData									= 0;
		ST[j].GMSymbol									= 2;
		ST[j].GLineWidth          			= 1;
		ST[j].GEpsilon									= (float) 100.;
		ST[j].GRange										= (float) 0.;
		ST[j].Color               			= GRAY;
		ST[j].GColor              			= DColor[j].Color;
	}

	for (j=0;j<=MAXNUMOFPARAMETERS;j++)
	{
		ST[j].LineWidth           = 1;
		ST[j].MSize               = 1;
		ST[j].GMSize							= 1;
		ST[j].MSymbol             = 1;
	}	
	  
	KoorLineWidth				= 1;

	ST[0].LineWidth			= 1;
	ST[0].ReverseRange	= 1;

	Color[0]						= GRAY;
	GColor[0]						= GRAY;

	for (j=1;j<=MAXNUMOFPARAMETERS;j++)
	{
		Color[j]  = BLACK;		
		GColor[j] = BLACK;	
	}	
}

// ------------------------------------------------------------------------------------------------
// InitD setzt alle Skalierungsfaktoren auf Defaultwerte.
// ------------------------------------------------------------------------------------------------

void InitD(void)
{    
	unsigned long  i = 0;
	    
	int            j = 0;
      
/**********************************************************************
*
*     C[j].S[1] = X_min
*     C[j].S[2] = X_max
*     C[j].S[3] = Y_min
*     C[j].S[4] = Y_max
*     
**********************************************************************/
      
	for (j=0;j<=MAXNUMOFPARAMETERS;j++)  
	{
		memset ((char *) C[j].Header, (int) '\0', 81);
		memset ((char *) C[j].GroupName, (int) '\0', 81);
		C[j].NumOfParametersInGroup = 0;
		C[j].counts = 0;
		C[j].S[1]   = (float) 0.;
		C[j].S[2]   = (float) 0.;
		C[j].S[3]   = (float) 0.;
		C[j].S[4]   = (float) 0.;
	}

	for (i=0;i<=gMaxMData;i++)  
	{
		Q[i].I = 0;
		Q[i].V = (float) 0.;
	}
}      

// ------------------------------------------------------------------------------------------------
// InitPattern laedt die Bitmaps.
// ------------------------------------------------------------------------------------------------

int InitPattern (void)
{
	FILE				*fin, *fout;

  StrFullName	Filename = "";

	int			err					= 1;
	int			i						= 0;
	int			j						= 0;
	int			length			= 0;
	int			NumOfBytes	= 0;
	
	char		*p;
  char    StrDummy[5];
	char    StrByte[9];
  char    StrBitmap[65];
    
	unsigned long	 ulDummy = 0;
	
// ------------------------------------------------------------------------------------------------

	GetBitmapName((char *) Filename);

	gNumOfBitmaps = 0;
	memset((char *) StrDummy, (int) '\0', 5);

	if ((fin = openFile((char *) Filename, "rb")) != NULL)
	{
		err = readFile(fin,InputStr,MAXNUMOFCHAR); // Header

		while ((++i < MAXNUMOFBITMAPS) && (err > 0))
		{
			gNumOfBitmaps++;
			
			for (j=0;j<=31;j++)
				BitPattern[i].bBitmap[j] = 0xFF;

			if ((err = readFile(fin,InputStr,MAXNUMOFCHAR)) != 0)
			{
				replaceStr(InputStr," ","");

				if ((p = strchr(InputStr, (int) '\t')) != NULL)
				{
					if ((length = (int) (p-InputStr)) > 8)
						length = 8;

					memset((char *) StrByte, (int) '\0', 9);
					strncpy((char *) StrByte, (char *) InputStr, (unsigned int) length); 
				  sscanf((char *) StrByte,"%d",&BitPattern[i].Width);
		      strncpy(InputStr,p+1,strlen(p));
				}
				else
				{
					err = -1;
				}

				if ((p = strchr(InputStr, (int) '\t')) != NULL)
				{
					if ((length = (int) (p-InputStr)) > 8)
						length = 8;
				
					memset((char *) StrByte, (int) '\0', 9);
					strncpy((char *) StrByte, (char *) InputStr, (unsigned int) length); 
					sscanf((char *) StrByte,"%d",&BitPattern[i].Height);
					strncpy(InputStr,p+1,strlen(p));
					memset((char *) BitPattern[i].Text, (int) '\0', 81);
					strncpy((char *) BitPattern[i].Text,InputStr,80);
				}
				else
				{
					err = -2;
				}

				memset(StrBitmap, (int) '\0', 65);
				NumOfBytes = BitPattern[i].Height * 2;
				j					 = 0;
				
				while ((j <= NumOfBytes-1) && (err > 0))
				{
					if ((err = readFile(fin,InputStr,MAXNUMOFCHAR)) != 0)
					{
						replaceStr(InputStr,".","1");
						replaceStr(InputStr,"*","0");

						if ((p = strchr(InputStr, (int) '\t')) != NULL)
				      strncpy(InputStr,p+1,strlen(p));

						if ((p = strchr(InputStr, (int) '\t')) != NULL)
				      strncpy(InputStr,p+1,strlen(p));

						strcat(InputStr,"\t");
						
					  if ((p = strchr(InputStr, (int) '\t')) != NULL)
						{
							if ((length = (int) (p-InputStr)) > 8)
								length = 8;

							memset((char *) StrByte, (int) '\0', 9);
							strncpy((char *) StrByte, (char *) InputStr, (unsigned int) length); 

							BitPattern[i].bBitmap[j] = (BYTE) strtoul((char *) StrByte, &p, 2);
							
				      strncpy(InputStr,p+1,strlen(p));
							memset((char *) StrByte, (int) '\0', 9);
							strncpy((char *) StrByte, (char *) InputStr, 8); 

							if (strlen(StrByte) > 0)
								BitPattern[i].bBitmap[j+1] = (BYTE) strtoul((char *) StrByte, &p, 2);

							j += 2;							
						}    
						else
						{
							err = -4;
						}
					}
				}
			}
		}

		closeFile(fin);
		return(0);
	}
	else
	{
		if ((fout = openNewFile((char *) Filename)) != NULL)
		{
      writeFile(fout,"Width in pixel\tHeight in pixel\tName\n");
      writeFile(fout,"8\t8\tBitmap2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.**.....\n");
      writeFile(fout,"\t\t.**.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....**.\n");
      writeFile(fout,"\t\t.....**.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.**..*..\n");
      writeFile(fout,"\t\t.**.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...**.\n");
      writeFile(fout,"\t\t.....**.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap4\n");
      writeFile(fout,"\t\t**......\n");
      writeFile(fout,"\t\t**......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap5\n");
      writeFile(fout,"\t\t*...**..\n");
      writeFile(fout,"\t\t....**..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t****..**\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap6\n");
      writeFile(fout,"\t\t*...**..\n");
      writeFile(fout,"\t\t....**..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t*****.**\n");
      writeFile(fout,"\t\t..***...\n");
      writeFile(fout,"\t\t..***...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap7\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap8\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t....****\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap9\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*****\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap10\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap11\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap12\n");
      writeFile(fout,"\t\t**..**..\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap13\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t**..**..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap14\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap15\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap16\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap17\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t....*.*.\n");
      writeFile(fout,"\t\t.....*.*\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*.*.....\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"8\t8\tBitmap18\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..***...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap19\n");
      writeFile(fout,"\t\t.**..**.\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t*...*...\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t**..**..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap20\n");
      writeFile(fout,"\t\t**......\n");
      writeFile(fout,"\t\t***.....\n");
      writeFile(fout,"\t\t***.....\n");
      writeFile(fout,"\t\t.*...**.\n");
      writeFile(fout,"\t\t....****\n");
      writeFile(fout,"\t\t...*****\n");
      writeFile(fout,"\t\t...*****\n");
      writeFile(fout,"\t\t....**..\n");
      writeFile(fout,"8\t8\tBitmap21\n");
      writeFile(fout,"\t\t**......\n");
      writeFile(fout,"\t\t*.*.....\n");
      writeFile(fout,"\t\t*.*.....\n");
      writeFile(fout,"\t\t.*...**.\n");
      writeFile(fout,"\t\t....*..*\n");
      writeFile(fout,"\t\t...*...*\n");
      writeFile(fout,"\t\t...*..*.\n");
      writeFile(fout,"\t\t....**..\n");
      writeFile(fout,"8\t8\tBitmap22\n");
      writeFile(fout,"\t\t**..**..\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap23\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap24\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t**..**..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap25\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap26\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...**...\n");
      writeFile(fout,"\t\t..*..*..\n");
      writeFile(fout,"\t\t..*..*..\n");
      writeFile(fout,"\t\t...**...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap27\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap28\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*.*..\n");
      writeFile(fout,"\t\t..*****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap29\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tBitmap30\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tG4\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tG5\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tG6\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tGr4\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tGr5\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tGr6\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.*..*...\n");
      writeFile(fout,"\t\t.*..*.*.\n");
      writeFile(fout,"\t\t..**....\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tX4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tX5\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tX6\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tO4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tO5\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tO7\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSs\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tgS\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tmS\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tffS\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tfS\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUu\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUs\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUls\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUt2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUt3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTt\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTu2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTl\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTs2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.******.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*.*....\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tS-X\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t*.......\n");
      writeFile(fout,"8\t8\tS-O\n");
      writeFile(fout,"\t\t.......*\n");
      writeFile(fout,"\t\t......*.\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t.*......\n");
      writeFile(fout,"\t\t*.......\n");
      writeFile(fout,"8\t8\tSu3-Gr\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu3-G\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu4-Gr\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu4-G\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUs-Gr\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUs-G\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t.*...*..\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t..*.*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t...*****\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t..*****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSu4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t...*****\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t*****...\n");
      writeFile(fout,"\t\t..*****.\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLt3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLts\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLt2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLs2\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLs3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLs4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSlu\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSt3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tSl4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTs4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t...*.*..\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTs3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t..*...*.\n");
      writeFile(fout,"\t\t...*.*..\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t..*.....\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTu3\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tTu4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tUt4\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"8\t8\tLu\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t...*....\n");
      writeFile(fout,"\t\t....*...\n");
      writeFile(fout,"\t\t.....*..\n");
      writeFile(fout,"\t\t.*****..\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");
      writeFile(fout,"\t\t........\n");

			closeFile(fout);
			return(-1);
		}
	}
	
	return(0);
}

