/*----------------------------------------------------------------/
/                                                                 /
/   Julday                                                        /
/                                                                 /
/   Dr. Rainer Sieger, Universitaet Bremen                        /
/                                                                 /
/   23.06.97                                                      /
/   12.04.99                                                      /
/                                                                 /
/----------------------------------------------------------------*/

#include <math.h>
#include <string.h>
#include <stdio.h>
#include <time.h>

#include <windows.h>

#include "Struct.h"
#include "Globals.h"

#include "Julday.h"
#include "replaceStr.h"

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

long CalcJulDay(int IYYY, int MM, int ID)
{
	long IGREG  = 588829L;
	long JulDay = 0L;

	int  JY			= IYYY;
	int  JM;
	int  JA;
       
      
// IF (IYYY.EQ.0) PAUSE 'There is no Year Zero.'
  if (JY < 0) 
    JY++;
  
  if (MM > 2)
	{
    JM = MM + 1;
	}
  else
  {
    JY--;        
    JM = MM + 13;
  }  
  
  JulDay = (long) (floor(365.25*JY) + floor(30.6001*JM) + ID + 1720995);
      
  if (ID+31L*(MM+12L*IYYY) >= IGREG)
  {
    JA     = (int) (0.01*JY);        
    JulDay = JulDay + (2-JA+(int)(0.25*JA));
  }  

	return(JulDay);      
}

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

float CalcJulTime(int Hour, int Minute, float Second)
{
	float  	JulTime 	= (float) 0.;
	
  JulTime  = (float) (Hour*3600);
  JulTime += (float) (Minute*60);  	
	JulTime += Second;

	JulTime /= (float) 86400.;
	
  return(JulTime);      
}

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

void CalcTime(float JulTime, int *Hour, int *Minute, int *Second)
{
	long iSecond = 0;

	JulTime  = JulTime - (int) JulTime;
	iSecond  = (long) (JulTime*86400.+0.5);
	*Hour    = (int) (iSecond/3600L);
	iSecond -= (long) *Hour*3600L;
	*Minute  = (int) (iSecond/60L);
	iSecond -= (long) *Minute*60L;	
	*Second  = (int) iSecond;
}

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

void CalcDate(long Julian, int *IYYY, int *MM, int *ID)
{
	long  IGREG  = 2299161L;
	long  JALPHA;
	long  JA, JB, JC,JD, JE;

	if (Julian >= IGREG)
	{
		JALPHA = (long) (((float) (Julian-1867216)-0.25)/36524.25);
		JA     = Julian + 1 + JALPHA - (long)(0.25*JALPHA);
	}  
	else
	{
		JA = Julian;
	}

	JB = JA + 1524;      
	JC = (long) (6680.0+((float) (JB-2439870)-122.1)/365.25);      
	JD = (long) (365*JC + (0.25*JC));      
	JE = (long) ((JB-JD)/30.6001);

	*ID = JB - JD - (long) (30.6001*JE);      
	*MM = JE - 1;

	if (*MM > 12) 
		*MM = *MM - 12;

	*IYYY = JC - 4715;

	if (*MM > 2) 
		--(*IYYY);

	if (*IYYY <= 0) 
		--(*IYYY);      
}

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

int StrToDate(char *String, int *Year, int *Month, int *Day)
{
	char  Dummy[32];
	
	char 	*delims = "-/.$T*";
	char 	*token;

	int  	i        = 0;	
	int  	a[4]     = {0,0,0,0};
	int  	Language = 0;
  int  	err      = 0;

//------------------------------------------------------------------

	strncpy(Dummy, String, 31);
  
	if ((token = strchr(Dummy, (int) '\t')) != NULL)
    *token = '\0';
	
	if (strlen(Dummy) < 2)
		return(0);			
	  
	if ((strchr(Dummy, (int) '/') - Dummy) > 0)  // US
	  Language = 1;
		
	if ((strchr(Dummy, (int) '.') - Dummy) > 0)	// German
	  Language = 2;
	
	if ((strchr(Dummy, (int) '$') - Dummy) > 0)	//
	  Language = 3;
	
	if ((strchr(Dummy, (int) '-') - Dummy) > 0) // ISO
		Language = 4;

	if (Language < 1)
	{		
	  Language = 5;
		replaceStr(Dummy," ","*");
		replaceStr(Dummy,"Jan","01");
		replaceStr(Dummy,"Feb","02");
		replaceStr(Dummy,"Mrz","03");
		replaceStr(Dummy,"Mar","03");
		replaceStr(Dummy,"Apr","04");
		replaceStr(Dummy,"May","05");
		replaceStr(Dummy,"Jun","06");
		replaceStr(Dummy,"Jul","07");
		replaceStr(Dummy,"Aug","08");
		replaceStr(Dummy,"Sep","09");
		replaceStr(Dummy,"Oct","10");
		replaceStr(Dummy,"Nov","11");
		replaceStr(Dummy,"Dec","12");
	}			

	token = strtok(Dummy,delims);

	while ((token != NULL) && (i < 3))
	{
		sscanf(token,"%d",&a[++i]);
		token = strtok(NULL,delims);
	}
	
	switch (i)
	{
	case 2:
		switch (Language)
		{
			case 1:	
				*Month = a[1];
				*Day	 = 15;	
				*Year  = a[2];
				isDate = 1;		
				break;

/*
fhrt dazu das auch ganz normale Zahlen als Datum interpretiert werden
			case 2:	
				*Day   = 15;
				*Month = a[1];
				*Year	 = a[2];	
				isDate = 1;		
				break;
*/

			case 3:	
				*Month = a[1];
				*Day   = 15;
				*Year	 = a[2];	
				isDate = 1;		
				break;

			case 4:	// ISO
				*Year	 = a[1];	
				*Month = a[2];
				*Day	 = 15;
				isDate = 1;		
				break;

			case 5:	
				*Day	 = 15;
				*Month = a[1];
				*Year	 = a[2];	
				isDate = 1;		
				break;

			default:
				isDate = 0;
				break;
		}		
		break;

	case 3:
		switch (Language)
		{
			case 1:	
				*Month = a[1];
				*Day	 = a[2];	
				*Year  = a[3];
				isDate = 1;		
				break;

			case 2:	
				*Day   = a[1];
				*Month = a[2];
				*Year	 = a[3];	
				isDate = 1;		
				break;

			case 3:	
				*Month = a[1];
				*Day   = a[2];
				*Year	 = a[3];	
				isDate = 1;		
				break;

			case 4:	
				*Year	 = a[1];	
				*Month = a[2];
				*Day	 = a[3];
				isDate = 1;		
				break;

			case 5:	
				*Day	 = a[1];
				*Month = a[2];
				*Year	 = a[3];	
				isDate = 1;		
				break;
		}		
		break;

	default:
		isDate = 0;
		break;
	}

	return( isDate );
}

//------------------------------------------------------------------
//------------------------------------------------------------------
//------------------------------------------------------------------

int StrToTime(char *String, int *Hour, int *Minute, float *Second)
{
	char  Dummy[32];
	
	char 	*delims = ":";
	char 	*token;
		
	int		PM = 0;	
	int   i  = 0;	
	
	float a[4] = {(float) 0.,(float) 0.,(float) 0.,(float) 0.};
	
//------------------------------------------------------------------
	
	strncpy(Dummy, String, 31);
  
	if ((token = strchr(Dummy, (int) '\t')) != NULL)
    *token = '\0';
	
	if (strlen(Dummy) < 2)
		return(0);			
  
	if ((token = strstr(Dummy, "AM")) != NULL)
    *token = '\0';
  
	if ((token = strstr(Dummy, "PM")) != NULL)
	{		
		PM = 12;		
    *token = '\0';
	}
	
	if ( (strchr(Dummy, (int) ':') == NULL) && (strchr(Dummy, (int) 'T') == NULL) )
	  return(0);	  	  	  

	while ((token = strchr(Dummy, (int) ' ')) != NULL)	
     strcpy(Dummy, token+1); 			

	while ((token = strchr(Dummy, (int) 'T')) != NULL)	
		strcpy(Dummy, token+1); 			
	 
	token = strtok(Dummy,delims);

	while ((token != NULL) && (i < 3))
	{
		sscanf(token,"%f",&a[++i]);
		token = strtok(NULL,delims);
	}
	
	*Hour    = (int) a[1] + PM;
	*Minute  = (int) a[2];
	*Second	 = a[3];	
	
	return(1);		
}

